# Teledetection

<p align="center">
<img src="doc/logo.png" width="320px">
<br>
<a href="https://forge.inrae.fr/teledec/teledetection/-/releases">
<img src="https://forge.inrae.fr/teledec/teledetection/-/badges/release.svg">
</a>
<a href="https://forge.inrae.fr/teledec/teledetection/-/commits/main">
<img src="https://forge.inrae.fr/teledec/teledetection/badges/main/pipeline.svg">
</a>
<a href="LICENSE">
<img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg">
</a>
<a href="https://forge.inrae.fr/teledec/teledetection/-/commits/main">
<img src="https://forge.inrae.fr/teledec/teledetection/badges/main/coverage.svg">

</p>

**teledetection** enables to use the [STAC based geospatial data infrastructure](https://www.stac.teledetection.fr) 
of *la Maison de la Teledetection*.

For more information read the [documentation](https://teledetection.readthedocs.io).

## Contact

- remi cresson @ inrae
- pablo boizeau @ ird

